@@ -1,7 +1,6 @@
 import time
 from datetime import datetime
 from enum import Enum
-from pathlib import Path
 from typing import Any, Dict, Literal, Optional
 
 from pydantic import AnyUrl, BaseModel, Field, stricturl, validator
@@ -11,7 +10,7 @@ class SlotDataSchema(BaseModel):
     class Config:
         validate_assignment = True
 
-    value_type: Literal["text", "bool", "float", "list", "categorical"] = Field(
+    value_type: Literal["text", "bool", "float", "list", "dict", "categorical", "int"] = Field(
         ...,
         title="Slot Type",
         description="Slot value type.",
